%DEMO_USER Demonstrates the usage of pdNCG solver for logistic regression
%problems:
%
% min tau*||x||_1 + phi(X,labels),
%
% when the solver is called with user defined function handles for the
% function phi(x), its gradient and hessian.
%
% X is the matrix which stores the training samples and y are the labels.
% The problem must be strongly convex.

% Copyright (c) 2014.  Kimon Fountoulakis and Jacek Gondzio.

clear;

% Load a problem (X,labels). This problem corresponds to the data for the
% heart_scale problem in 
% http://www.csie.ntu.edu.tw/~cjlin/libsvmtools/datasets/binary.html#heart
load data_lg.mat

[~, n] = size(X);

% Options.
opts.problem = 'user';
opts.n = n;
opts.tau  = 1;

opts.gradient_phi = @(x)   gradient_phi(x, X, labels);
opts.hessian_phi  = @(x,q) hessian_phi(x, q, X, labels);
opts.phi          = @(x)   phi(x, X, labels);   
       
% Call pdNCG.
[x, y, out] = pdNCGinterface(opts);

fprintf('CPU time: %d \n', out.cput);

clear;
