function opts = checkOptions_W(opts)
%CHECKOPTION Checks the input arguments for pdNCG_W.
%
% Copyright (c) 2014.Ioannis Dassios, Kimon Fountoulakis and Jacek Gondzio.

%%
if ~isfield(opts, {'n'})  
    error('The number of variables n is not provided.');
end    

%%
if ~isfield(opts, {'A'})
    error('The measurement matrix opts.A is required.');
else
    if ~isa(opts.A, 'A_operator') && ~(sum(size(opts.A) > 1) == 2)
        error('The argument opts.A must be a matrix or of type "A_operator which operates on vectors or a MATLAB matrix".');
    end 
end
 
%%
if ~isfield(opts, {'W'})
    error('The matrix opts.W is required.');
else
    if ~isa(opts.W, 'A_operator') && ~(sum(size(opts.W) > 1) == 2)
        error('The argument opts.W must be a matrix or of type "A_operator which operates on vectors or a MATLAB matrix".');
    end 
end
   
%%
if ~isfield(opts, {'b'})    
    error('Samples vector b for the Least-Squares fidelity term is required.');
end

%%
sizes_b = size(opts.b);
if sizes_b(1) > 1 && sizes_b(2) > 1
    error('Samples vector b should be a column vector.');
end
if sizes_b(2) > 1
    opts.b = opts.b';
end   

%%
if ~isfield(opts, {'tau'})    
    error('The regularization parameter tau is required.');
else
    if opts.tau <= 0, 
        error('The regularization parameter tau, i.e. opts.tau, must be greater than 0.'); 
    end
end

%%
if ~isfield(opts, {'cont_steps'})  
    order_tau = floor(log(abs(opts.tau))./log(10));
    order_mu  = floor(log(abs(opts.mu))./log(10));
    order = min(order_tau,order_mu);
    if order < -1
         opts.cont_steps = -order;  
    else
        opts.cont_steps = 1;  
    end        
else
    if opts.cont_steps <= 0
        error('Continuation steps must be greater than 0.'); 
    end
end

%%
if ~isfield(opts, {'prec_tol'})    
    opts.prec_tol = 1.0e-4;
else
    if opts.prec_tol <= 0
        error('Parameter prec_tol must be positive'); 
    end    
end

%%
if ~isfield(opts, {'x0'})  
    opts.x0 = zeros(opts.n,1);
else
    size_x0 = size(opts.x0);
    if size_x0(1) > 1 && size_x0(2) > 1
        error('The argument opts.x0 should be a vector.');
    end
    if size_x0(2) > 1
        opts.x0 = opts.x0';
    end
end

%%
if ~isfield(opts, {'y0'})  
    Wtx  = opts.W'*opts.x0;
    opts.y0 = sign(Wtx).*min(abs(Wtx),1);
else
    size_y0 = size(opts.y0);
    if size_y0(1) > 1 && size_y0(2) > 1
        error('The argument opts.y0 should be a vector.');
    end
    if size_y0(2) > 1
        opts.y0 = opts.y0';
    end
    if size_y0(1) ~= length(opts.W'*opts.x0)
        error('The length of vector opts.y0 must be equal to number of rows of matrix opts.W.');
    end
end