function opts = checkOptions_lg(opts)
%CHECKOPTION Checks the input arguments for pdNCG_lg.
%
% Copyright (c) 2014.Ioannis Dassios, Kimon Fountoulakis and Jacek Gondzio.

%%
if ~isfield(opts, {'n'})  
    error('The number of variables n is not provided.');
end    

%%
if ~isfield(opts, {'X'})    
    error('The training samples matrix X is required.');
end
if ~isfield(opts, {'y'})    
    error('Labels vector y is required (must be -1 or 1).');
end
if ~ismatrix(opts.X)
    error('X must be a matrix m by n, with m>1 and n>1.');
end

%%
sizes_X = size(opts.X);
if (sizes_X(1)==1 || sizes_X(2)==1)
    error('X must be a matrix m by n, with m>1 and n>1.');
end

%%
sizes_y = size(opts.y);
if sizes_y(1) > 1 && sizes_y(2) > 1
    error('Labels vector y should be a column vector.');
end
if sizes_y(2) > 1
    opts.y = opts.y';
end
   
%%
if sizes_X(2) ~= opts.n
    text  = 'Dimensions mismatch. The number of columns of matrix X'; 
    text2 = ' must be the same as the number of unknown variables.';
    error([text,text2]);
end
sizes_y = size(opts.y);
if sizes_X(1) ~= sizes_y(1)
    text  = 'Dimensions mismatch. The number of rows of matrix X must';
    text2 = ' be the same as the length of y.\n';
    error([text,text2]);
end    

%%
if ~isfield(opts, {'tau'})    
    error('The regularization parameter tau is required.');
else
    if opts.tau <= 0, 
        error('The regularization parameter tau, i.e. opts.tau, must be greater than 0.'); 
    end
end

%%
if ~isfield(opts, {'rankupdates'})  
    opts.rankupdates = 6;  
else
    if opts.rankupdates <= 0 || opts.rankupdates > opts.n
        error('The rank updates must be greater than 0 and less or equal to n.'); 
    end
end

%%
if ~isfield(opts, {'cont_steps'})  
    opts.cont_steps = 1;
else
    if opts.cont_steps <= 0
        error('Continuation steps must be greater than 0.'); 
    end
end

%%
if ~isfield(opts, {'x0'})  
    opts.x0 = zeros(opts.n,1);
else
    size_x0 = size(opts.x0);
    if size_x0(1) > 1 && size_x0(2) > 1
        error('The argument opts.x0 should be a vector.');
    end
    if size_x0(2) > 1
        opts.x0 = opts.x0';
    end
end

%%
if ~isfield(opts, {'y0'})  
    D  = 1./sqrt(opts.mu^2 + opts.x0.^2);
    Dx = D.*opts.x0;
    opts.y0 = sign(Dx).*min(abs(Dx),1);
else
    size_y0 = size(opts.y0);
    if size_y0(1) > 1 && size_y0(2) > 1
        error('The argument opts.y0 should be a vector.');
    end
    if size_y0(2) > 1
        opts.y0 = opts.y0';
    end
    if size_y0(1) ~= opts.n
        error('The length of vector opts.y0 must be equal to opts.n.');
    end
end
