function opts = checkOptions_ls(opts)
%CHECKOPTION Checks the input arguments for pdNCG_ls.
%
% Copyright (c) 2014.Ioannis Dassios, Kimon Fountoulakis and Jacek Gondzio.

%%
if ~isfield(opts, {'n'})  
    error('The number of variables n is not provided.');
end    

%%
if ~isfield(opts, {'A'})
    error('The measurement matrix opts.A is required.');
else
    if ~isa(opts.A, 'A_operator') && ~(sum(size(opts.A) > 1) == 2)
        error('opts.A must be a MATLAB matrix or of type "A_operator" which operates on vectors.');
    end 
end

%%
if ~isfield(opts, {'b'})    
    error('Data vector b for the Least-Squares fidelity term is required.');
end

%%
sizes_b = size(opts.b);
if sizes_b(1) > 1 && sizes_b(2) > 1
    error('Samples vector b should be a column vector.');
end
if sizes_b(2) > 1
    opts.b = opts.b';
end  

%%
if ~isfield(opts, {'tau'})    
    error('opts.tau is required.');
else
    if opts.tau <= 0, 
        error('opts.tau must be greater than 0.'); 
    end
end

%%
if ~isfield(opts, {'rankupdates'})  
    opts.rankupdates = 6;  
else
    if opts.rankupdates <= 0 || opts.rankupdates > opts.n
        error('The rank updates must be greater than 0 and less or equal to n.'); 
    end
end

%%
if ~isfield(opts, {'cont_steps'})  
    opts.cont_steps = 1;
else
    if opts.cont_steps <= 0
        error('Continuation steps must be greater than 0.'); 
    end
end

%%
if ~isfield(opts, {'x0'})  
    opts.x0 = zeros(opts.n,1);
else
    size_x0 = size(opts.x0);
    if size_x0(1) > 1 && size_x0(2) > 1
        error('The argument opts.x0 should be a vector.');
    end
    if size_x0(2) > 1
        opts.x0 = opts.x0';
    end
end

%%
if ~isfield(opts, {'y0'})  
    D  = 1./sqrt(opts.mu^2 + opts.x0.^2);
    Dx = D.*opts.x0;
    opts.y0 = sign(Dx).*min(abs(Dx),1);
else
    size_y0 = size(opts.y0);
    if size_y0(1) > 1 && size_y0(2) > 1
        error('The argument opts.y0 should be a vector.');
    end
    if size_y0(2) > 1
        opts.y0 = opts.y0';
    end
    if size_y0(1) ~= opts.n
        error('The length of vector opts.y0 must be equal to opts.n.');
    end
end